@@ -41,7 +41,7 @@ sub function_to_date {
             { prompt => 'Locale: ' }
         ];
     }
-    return $sf->__format_function( $sql, $clause, $func, $cols, $r_data );
+    return $sf->__format_function( $sql, $clause, $func, $cols, $r_data, $r_data, $add_args_data ); ##
 }
 
 
@@ -197,7 +197,7 @@ sub function_to_epoch {
     }
     elsif ( $driver eq 'Oracle' ) {
         my $args_data = [
-            { prompt => 'Column type: ', history => [ qw(DATE TIMESTAMP TIMESTAMP_TZ) ], history_only => 1 }
+            { prompt => 'Column type: ', unquote => 1, history => [ qw(DATE TIMESTAMP TIMESTAMP_TZ) ], history_only => 1 } ##
         ];
         my ( $column_type ) = $ga->get_arguments( $sql, $clause, $func, $args_data, $r_data );
         $column_type = uc $column_type;
